using UnityEngine;
using System.Collections;

[RequireComponent( typeof( SpriteRenderer ) )]
public class BoardTile : MonoBehaviour
{
    public Sprite[] tileTypes;

    // The tile's sprite is changed by changing the tile index
    // (which references the tileTypes array). Setting it to -1
    // clears the tile.
    int _tileIndex = -1;
    public int TileIndex
    {
        get { return _tileIndex; }
        set
        {
            if ( tileTypes.Length == 0 || value < 0 )
            {
                _tileIndex = -1;
            }
            else if ( value >= tileTypes.Length )
            {
                _tileIndex = tileTypes.Length - 1;
            }
            else
            {
                _tileIndex = value;
            }

            if ( _tileIndex == -1 )
            {
                renderer.enabled = false;
            }
            else
            {
                renderer.enabled = true;
                renderer.sprite = tileTypes[_tileIndex];
            }
        }
    }

    public bool IsOccupied { get { return _tileIndex != -1; } }

    // 'new' required to override deprecated renderer property
    new SpriteRenderer renderer;

	// Use this for initialization
	void Awake () {
        renderer = GetComponent<SpriteRenderer>();
        renderer.sprite = null;
        renderer.enabled = false;
	}
}
