﻿using UnityEngine;
using System.Collections;

public class PreviewBoard : MonoBehaviour {

    [SerializeField] GameObject boardTilePrefab;

    // Width and height are equal for this window 
    const int BOARD_SIZE = 5;
    static Point2 BLOCK_POSITION { get { return new Point2( 2, 2 ); } }

    BoardTile[,] grid = new BoardTile[BOARD_SIZE, BOARD_SIZE];

    void Awake() {
        // Set up the smaller board
        for ( int x = 0; x < BOARD_SIZE; x++ ) {
            for ( int y = 0; y < BOARD_SIZE; y++ ) {
                var newObj = Instantiate( boardTilePrefab ) as GameObject;
                newObj.transform.SetParent( this.transform );
                newObj.transform.localPosition = new Vector3( -2.5f, -2.5f, 0f ) + new Vector3( x, y, 0 );
                grid[x, y] = newObj.GetComponent<BoardTile>();
            }
        }
    }

    // Clear the last block and replace it with the new type
    public void SetBlockPreview( BlockType type ) {
        var newBlock = new Block( type, BLOCK_POSITION );
        for ( int x = 0; x < BOARD_SIZE; x++ ) {
            for ( int y = 0; y < BOARD_SIZE; y++ ) {
                if ( newBlock.GridPositions.Contains( new Point2( x, y ) ) ) {
                    grid[x, y].TileIndex = (int)type;
                } else {
                    grid[x, y].TileIndex = -1;
                }
            }
        }
    }

    void OnDrawGizmos() {
        Gizmos.color = Color.green;
        Gizmos.DrawWireCube( transform.position, transform.localScale * BOARD_SIZE );
    }
}
